@@ -1,5 +1,6 @@
 use std::str;
 
+use async_trait::async_trait;
 use clap::{App, ArgMatches, SubCommand};
 
 use casper_client::Error;
@@ -14,6 +15,7 @@ enum DisplayOrder {
     RpcId,
 }
 
+#[async_trait]
 impl<'a, 'b> ClientCommand<'a, 'b> for ListRpcs {
     const NAME: &'static str = "list-rpcs";
     const ABOUT: &'static str = "List all currently supported RPCs";
@@ -29,11 +31,13 @@ impl<'a, 'b> ClientCommand<'a, 'b> for ListRpcs {
             .arg(common::rpc_id::arg(DisplayOrder::RpcId as usize))
     }
 
-    fn run(matches: &ArgMatches<'_>) -> Result<Success, Error> {
+    async fn run(matches: &ArgMatches<'a>) -> Result<Success, Error> {
         let maybe_rpc_id = common::rpc_id::get(matches);
         let node_address = common::node_address::get(matches);
         let verbosity_level = common::verbose::get(matches);
 
-        casper_client::list_rpcs(maybe_rpc_id, node_address, verbosity_level).map(Success::from)
+        casper_client::list_rpcs(maybe_rpc_id, node_address, verbosity_level)
+            .await
+            .map(Success::from)
     }
 }
